{% extends "lazycrud/object_form.html" %}
{% load crispy_forms_tags %}
{% load i18n %}

{% block form_content %}

<form role="form" method="POST" action="" {% if form.is_multipart %}enctype="multipart/form-data"{% endif %}>
    <div class="row">
        <div class="col-lg-6 col-lg-offset-2 form-horizontal">
            {% crispy form form_horizontal_helper %}
        </div> <!-- /.col-lg-* -->
    </div> <!-- /.row -->
    <div class="row">
        <div class="col-lg-12">
            {% crispy formset table_inline_formset %}
            <div class="form-actions">
                <div class="col-lg-12 text-center">
                    <button type="submit" class="btn btn-primary btn-lg">{% trans 'Save' %}</button>
                </div>
            </div>
        </div> <!-- /.col-lg-* -->
    </div> <!-- /.row -->
</form>

{% endblock %}
