{% load static %}

<link href="{% static 'lazycrud/css/datatables.min.css' %}" rel="stylesheet">
<link href="{% static 'lazycrud/css/dataTables.fontAwesome.css' %}" rel="stylesheet">
{% if view.fixed_header %}
<link href="{% static 'lazycrud/css/fixedHeader.dataTables.min.css' %}" rel="stylesheet">
{% endif %}
