{% load static %}

<script src="{% static 'lazycrud/js/dataTables/datatables.min.js' %}"></script>
<script src="{% static 'lazycrud/js/dataTables/moment.min.js' %}"></script>
<script src="{% static 'lazycrud/js/dataTables/datetime-moment.js' %}"></script>
{% if view.fixed_header %}
<script src="{% static 'lazycrud/js/dataTables/dataTables.fixedHeader.min.js' %}"></script>
{% endif %}
<script id="object-list-script" src="{% static 'lazycrud/js/object_list.js' %}"></script>
